#
# spec file for package perl-Test-LeakTrace
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-LeakTrace
Name:           perl-Test-LeakTrace
Version:        0.17
Release:        1.15
Summary:        Traces memory leaks
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/L/LE/LEEJO/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
'Test::LeakTrace' provides several functions that trace memory leaks. This
module scans arenas, the memory allocation system, so it can detect any
leaked SVs in given blocks.

*Leaked SVs* are SVs which are not released after the end of the scope they
have been created. These SVs include global variables and internal caches.
For example, if you call a method in a tracing block, perl might prepare a
cache for the method. Thus, to trace true leaks, 'no_leaks_ok()' and
'leaks_cmp_ok()' executes a block more than once.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes example README

%changelog
* Wed Jan  6 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.17
  see /usr/share/doc/packages/perl-Test-LeakTrace/Changes
  0.17 2021-01-05
  - Point issue tracker at github
* Sun Jun 18 2017 coolo@suse.com
- updated to 0.16
  see /usr/share/doc/packages/perl-Test-LeakTrace/Changes
  0.16 2017-06-17
  - Fix build and test issues with perl5.26 due to removal of . from @INC
    (PR #4 - thanks to jkeenan)
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.15
  see /usr/share/doc/packages/perl-Test-LeakTrace/Changes
  0.15 2014-11-14 07:51:22+0900
  - Fix test failure on Windows (#1)
* Sun Nov 20 2011 coolo@suse.com
- update to 0.14
  - Fix Test::Valgrind failures (thanks to @shohex)
* Sun May  1 2011 coolo@opensuse.org
- updated to 0.13
  - Fix tests for older perls
  - Use ">= 0", instead of "== 0" for no_leaks_ok()
  - Add count_sv() to count all the SVs in a perl interpreter
  - Resolve RT #58133: "False-positive related to XS code"
* Tue Mar 15 2011 cfarrell@novell.com
- license update: GPL+ or Artistic
  Only license found in package is Perl license which expands to GPL+ or Artistic
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Dec 26 2009 lars@linux-schulserver.de
- initial version 0.10
